#include "project.h"

volatile int pit_flag = 0 ;
volatile uint32_t pit_count = 0 ;
uint32_t pit_interval_ms = 1000 ; // flag each 1 sec
#define PWM1_PERIOD (65535u)
#define PWM1_PATTERN1 (10000u)
#define PWM1_PATTERN2 (60000u)

CY_ISR(SysTick_ISR)
{
    pit_count++ ;
    if (pit_count >= pit_interval_ms) {
        pit_flag = 1 ;
        pit_count = 0 ;
    }
}

int find_empty_slot(void)
{
    int result = -1 ;
    uint32_t i ;
    for (i = 0 ; i < CY_SYS_SYST_NUM_OF_CALLBACKS ; i++ ) {
        if (CySysTickGetCallback(i) == NULL) {
            result = i ;
            break ;
        }
    }
    return(result) ;
}

void init_systick(void)
{
    int sys_tick_slot = 0 ;
    
    sys_tick_slot = find_empty_slot() ;
    if (sys_tick_slot < 0) {
        while(1) { } /* halting here */
    } else {
        CySysTickStart() ;
        CySysTickSetCallback(sys_tick_slot, SysTick_ISR) ;
    }
    
    CySysTickStart();
}

void init_pwm(void)
{
    PWM_Start() ;
    PWM_WritePeriod(PWM1_PERIOD);
    PWM_WriteCompare(PWM1_PATTERN1);
    PWM_WriteCompareBuf(PWM1_PATTERN2);
    PWM_SetCompareSwap(1u);    
}

void init_hardware(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */    
    
    init_pwm() ;
    
    init_systick() ;
}
    
int main(void)
{
    init_hardware() ;
    
    for(;;)
    {
        if (pit_flag) {
            pit_flag = 0 ;
            PWM_TriggerCommand(PWM_MASK, PWM_CMD_CAPTURE) ;
        }
    }
}

